==> grafeas-1.4.1.tar.gz: grafeas-1.4.1/grafeas/grafeas_v1/services/grafeas/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
import pkg_resources

import google.auth  # type: ignore
import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry as retries
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.protobuf import empty_pb2  # type: ignore
from grafeas.grafeas_v1.types import grafeas

try:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
        gapic_version=pkg_resources.get_distribution("grafeas",).version,
    )
except pkg_resources.DistributionNotFound:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()


class GrafeasTransport(abc.ABC):
    """Abstract transport class for Grafeas."""

    AUTH_SCOPES = ()

    DEFAULT_HOST: str = ""

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: ga_credentials.Credentials = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """
        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )
        elif credentials is None:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.get_occurrence: gapic_v1.method.wrap_method(
                self.get_occurrence,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=30.0,
                ),
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.list_occurrences: gapic_v1.method.wrap_method(
                self.list_occurrences,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=30.0,
                ),
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.delete_occurrence: gapic_v1.method.wrap_method(
                self.delete_occurrence,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=30.0,
                ),
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.create_occurrence: gapic_v1.method.wrap_method(
                self.create_occurrence, default_timeout=30.0, client_info=client_info,
            ),
            self.batch_create_occurrences: gapic_v1.method.wrap_method(
                self.batch_create_occurrences,
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.update_occurrence: gapic_v1.method.wrap_method(
                self.update_occurrence, default_timeout=30.0, client_info=client_info,
            ),
            self.get_occurrence_note: gapic_v1.method.wrap_method(
                self.get_occurrence_note,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=30.0,
                ),
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.get_note: gapic_v1.method.wrap_method(
                self.get_note,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=30.0,
                ),
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.list_notes: gapic_v1.method.wrap_method(
                self.list_notes,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=30.0,
                ),
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.delete_note: gapic_v1.method.wrap_method(
                self.delete_note,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=30.0,
                ),
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.create_note: gapic_v1.method.wrap_method(
                self.create_note, default_timeout=30.0, client_info=client_info,
            ),
            self.batch_create_notes: gapic_v1.method.wrap_method(
                self.batch_create_notes, default_timeout=30.0, client_info=client_info,
            ),
            self.update_note: gapic_v1.method.wrap_method(
                self.update_note, default_timeout=30.0, client_info=client_info,
            ),
            self.list_note_occurrences: gapic_v1.method.wrap_method(
                self.list_note_occurrences,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=30.0,
                ),
                default_timeout=30.0,
                client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

       .. warning::
            Only call this method if the transport is NOT shared
            with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def get_occurrence(
        self,
    ) -> Callable[
        [grafeas.GetOccurrenceRequest],
        Union[grafeas.Occurrence, Awaitable[grafeas.Occurrence]],
    ]:
        raise NotImplementedError()

    @property
    def list_occurrences(
        self,
    ) -> Callable[
        [grafeas.ListOccurrencesRequest],
        Union[
            grafeas.ListOccurrencesResponse, Awaitable[grafeas.ListOccurrencesResponse]
        ],
    ]:
        raise NotImplementedError()

    @property
    def delete_occurrence(
        self,
    ) -> Callable[
        [grafeas.DeleteOccurrenceRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def create_occurrence(
        self,
    ) -> Callable[
        [grafeas.CreateOccurrenceRequest],
        Union[grafeas.Occurrence, Awaitable[grafeas.Occurrence]],
    ]:
        raise NotImplementedError()

    @property
    def batch_create_occurrences(
        self,
    ) -> Callable[
        [grafeas.BatchCreateOccurrencesRequest],
        Union[
            grafeas.BatchCreateOccurrencesResponse,
            Awaitable[grafeas.BatchCreateOccurrencesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def update_occurrence(
        self,
    ) -> Callable[
        [grafeas.UpdateOccurrenceRequest],
        Union[grafeas.Occurrence, Awaitable[grafeas.Occurrence]],
    ]:
        raise NotImplementedError()

    @property
    def get_occurrence_note(
        self,
    ) -> Callable[
        [grafeas.GetOccurrenceNoteRequest], Union[grafeas.Note, Awaitable[grafeas.Note]]
    ]:
        raise NotImplementedError()

    @property
    def get_note(
        self,
    ) -> Callable[
        [grafeas.GetNoteRequest], Union[grafeas.Note, Awaitable[grafeas.Note]]
    ]:
        raise NotImplementedError()

    @property
    def list_notes(
        self,
    ) -> Callable[
        [grafeas.ListNotesRequest],
        Union[grafeas.ListNotesResponse, Awaitable[grafeas.ListNotesResponse]],
    ]:
        raise NotImplementedError()

    @property
    def delete_note(
        self,
    ) -> Callable[
        [grafeas.DeleteNoteRequest], Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]]
    ]:
        raise NotImplementedError()

    @property
    def create_note(
        self,
    ) -> Callable[
        [grafeas.CreateNoteRequest], Union[grafeas.Note, Awaitable[grafeas.Note]]
    ]:
        raise NotImplementedError()

    @property
    def batch_create_notes(
        self,
    ) -> Callable[
        [grafeas.BatchCreateNotesRequest],
        Union[
            grafeas.BatchCreateNotesResponse,
            Awaitable[grafeas.BatchCreateNotesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def update_note(
        self,
    ) -> Callable[
        [grafeas.UpdateNoteRequest], Union[grafeas.Note, Awaitable[grafeas.Note]]
    ]:
        raise NotImplementedError()

    @property
    def list_note_occurrences(
        self,
    ) -> Callable[
        [grafeas.ListNoteOccurrencesRequest],
        Union[
            grafeas.ListNoteOccurrencesResponse,
            Awaitable[grafeas.ListNoteOccurrencesResponse],
        ],
    ]:
        raise NotImplementedError()


__all__ = ("GrafeasTransport",)

==> grafeas-1.4.5.tar.gz: grafeas-1.4.5/grafeas/grafeas_v1/services/grafeas/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
import pkg_resources

import google.auth  # type: ignore
import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry as retries
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.protobuf import empty_pb2  # type: ignore
from grafeas.grafeas_v1.types import grafeas

try:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
        gapic_version=pkg_resources.get_distribution(
            "grafeas",
        ).version,
    )
except pkg_resources.DistributionNotFound:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()


class GrafeasTransport(abc.ABC):
    """Abstract transport class for Grafeas."""

    AUTH_SCOPES = ()

    DEFAULT_HOST: str = ""

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: ga_credentials.Credentials = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """

        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )
        elif credentials is None:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.get_occurrence: gapic_v1.method.wrap_method(
                self.get_occurrence,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=30.0,
                ),
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.list_occurrences: gapic_v1.method.wrap_method(
                self.list_occurrences,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=30.0,
                ),
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.delete_occurrence: gapic_v1.method.wrap_method(
                self.delete_occurrence,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=30.0,
                ),
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.create_occurrence: gapic_v1.method.wrap_method(
                self.create_occurrence,
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.batch_create_occurrences: gapic_v1.method.wrap_method(
                self.batch_create_occurrences,
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.update_occurrence: gapic_v1.method.wrap_method(
                self.update_occurrence,
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.get_occurrence_note: gapic_v1.method.wrap_method(
                self.get_occurrence_note,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=30.0,
                ),
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.get_note: gapic_v1.method.wrap_method(
                self.get_note,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=30.0,
                ),
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.list_notes: gapic_v1.method.wrap_method(
                self.list_notes,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=30.0,
                ),
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.delete_note: gapic_v1.method.wrap_method(
                self.delete_note,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=30.0,
                ),
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.create_note: gapic_v1.method.wrap_method(
                self.create_note,
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.batch_create_notes: gapic_v1.method.wrap_method(
                self.batch_create_notes,
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.update_note: gapic_v1.method.wrap_method(
                self.update_note,
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.list_note_occurrences: gapic_v1.method.wrap_method(
                self.list_note_occurrences,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=30.0,
                ),
                default_timeout=30.0,
                client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

        .. warning::
             Only call this method if the transport is NOT shared
             with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def get_occurrence(
        self,
    ) -> Callable[
        [grafeas.GetOccurrenceRequest],
        Union[grafeas.Occurrence, Awaitable[grafeas.Occurrence]],
    ]:
        raise NotImplementedError()

    @property
    def list_occurrences(
        self,
    ) -> Callable[
        [grafeas.ListOccurrencesRequest],
        Union[
            grafeas.ListOccurrencesResponse, Awaitable[grafeas.ListOccurrencesResponse]
        ],
    ]:
        raise NotImplementedError()

    @property
    def delete_occurrence(
        self,
    ) -> Callable[
        [grafeas.DeleteOccurrenceRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def create_occurrence(
        self,
    ) -> Callable[
        [grafeas.CreateOccurrenceRequest],
        Union[grafeas.Occurrence, Awaitable[grafeas.Occurrence]],
    ]:
        raise NotImplementedError()

    @property
    def batch_create_occurrences(
        self,
    ) -> Callable[
        [grafeas.BatchCreateOccurrencesRequest],
        Union[
            grafeas.BatchCreateOccurrencesResponse,
            Awaitable[grafeas.BatchCreateOccurrencesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def update_occurrence(
        self,
    ) -> Callable[
        [grafeas.UpdateOccurrenceRequest],
        Union[grafeas.Occurrence, Awaitable[grafeas.Occurrence]],
    ]:
        raise NotImplementedError()

    @property
    def get_occurrence_note(
        self,
    ) -> Callable[
        [grafeas.GetOccurrenceNoteRequest], Union[grafeas.Note, Awaitable[grafeas.Note]]
    ]:
        raise NotImplementedError()

    @property
    def get_note(
        self,
    ) -> Callable[
        [grafeas.GetNoteRequest], Union[grafeas.Note, Awaitable[grafeas.Note]]
    ]:
        raise NotImplementedError()

    @property
    def list_notes(
        self,
    ) -> Callable[
        [grafeas.ListNotesRequest],
        Union[grafeas.ListNotesResponse, Awaitable[grafeas.ListNotesResponse]],
    ]:
        raise NotImplementedError()

    @property
    def delete_note(
        self,
    ) -> Callable[
        [grafeas.DeleteNoteRequest], Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]]
    ]:
        raise NotImplementedError()

    @property
    def create_note(
        self,
    ) -> Callable[
        [grafeas.CreateNoteRequest], Union[grafeas.Note, Awaitable[grafeas.Note]]
    ]:
        raise NotImplementedError()

    @property
    def batch_create_notes(
        self,
    ) -> Callable[
        [grafeas.BatchCreateNotesRequest],
        Union[
            grafeas.BatchCreateNotesResponse,
            Awaitable[grafeas.BatchCreateNotesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def update_note(
        self,
    ) -> Callable[
        [grafeas.UpdateNoteRequest], Union[grafeas.Note, Awaitable[grafeas.Note]]
    ]:
        raise NotImplementedError()

    @property
    def list_note_occurrences(
        self,
    ) -> Callable[
        [grafeas.ListNoteOccurrencesRequest],
        Union[
            grafeas.ListNoteOccurrencesResponse,
            Awaitable[grafeas.ListNoteOccurrencesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def kind(self) -> str:
        raise NotImplementedError()


__all__ = ("GrafeasTransport",)
